Gallery — MoviePy 1.0.1 documentation

# Gallery

Here are a few projects using MoviePy. The gallery will fill up as more people start using MoviePy (which is currently one year old). If you have a nice project using MoviePy let us know !

## Videos edited with Moviepy

### The Cup Song Covers Mix

This mix of 60 covers of the Cup Song demonstrates the non-linear video editing capabilities of MoviePy. Here is the (undocumented) MoviePy code that generated the video.

### The (old) MoviePy reel video.

Made when MoviePy was a few weeks old and not as good as now. The code for most scenes can be found in the Example Scripts.

## Animations edited with MoviePy

### GIFs made from videos

This gifs tutorial gives you the basics to make gifs from video files (cutting, croping, adding text…). The last example shows how to remove a (still) background to keep only the animated part of a video.

### Vector Animations

This vector animations tutorial shows how to combine MoviePy with Gizeh to create animations:

It is also possible to combine MoviePy with other graphic librairies like matplotlib, etc.

### 3D animations

This 3d animation tutorial shows how to combine MoviePy with Vapory, a library to render 3D scenes using the free ray-tracer POV-Ray

With Vapory and MoviePy you can for instance embed a movie in a 3D scene:

Or render the result of this physics simulation made with PyODE (script):

Or use this script to make piano animations from MIDI files (which are some sort of electronic sheet music):

## Data animations

This data animation tutorial shows how to use MoviePy to animate the different Python vizualization libraries: Mayavi, Vispy, Scikit-image, Matplotlib, etc.

## Scientific or technological projects

### Piano rolls transcription to sheet music

This transcribing piano rolls blog post explains how to transform a video of a piano roll performance into playable sheet music. MoviePy is used for the frame-by-frame analysis of the piano roll video. The last video is also edited with MoviePy:

## Misc. Programs and Scripts using MoviePy

## Kapwing

Kapwing is an online video meme generator. Content creators use Kapwing to add text around their videos, which results in higher engagement / views on social media sites like Facebook. Kapwing’s creation process is powered by MoviePy! MoviePy is used to add the text, borders, and attribution directly to the uploaded videos.

## Rinconcam

Rincomcam is a camera which films surfers on the Californian beach of Point Rincon. At the end of each day it cuts together a video, puts it online, and tweets it. Everything is entirely automatized with Python. MoviePy is used to add transitions, titles and music to the videos.

### Videogrep

Videogrep is a python script written by Sam Lavigne, that goes through the subtitle tracks of movies and makes supercuts based on what it finds. For instance, here is an automatic supercut of every time the White House press secretary tells us what he can tell us:

Here are Videogrep’s introductory blog post and the Github Videogrep page.

If you liked it, also have a look at these Videogrep-inspired projects:

This Videogrep blog post attempts to cut a video precisely at the beginning and end of sentences or words:

    words = ["Americans", "must", "develop", "open ", "source",
              " software", "for the", " rest ", "of the world",
              "instead of", " soldiers"]
    numbers = [3,0,4,3,4,0,1,2,0,1,0] # take clip number 'n'

    cuts = [find_word(word)[n] for (word,n) in zip(words, numbers)]
    assemble_cuts(cuts, "fake_speech.mp4")

This other post uses MoviePy to automatically cut together all the highlights of a soccer game, based on the fact that the crowd cheers louder when something interesting happens. All in under 30 lines of Python: